@@ -53,16 +53,9 @@ as_scalar_redirect<N>::apply(const T1& X)
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::elem_type eT;
-  
   const Proxy<T1> P(X);
   
-  if(P.get_n_elem() != 1)
-    {
-    arma_debug_check(true, "as_scalar(): expression doesn't evaluate to exactly one element");
-    
-    return Datum<eT>::nan;
-    }
+  arma_debug_check( (P.get_n_elem() != 1), "as_scalar(): expression must evaluate to exactly one element" );
   
   return (Proxy<T1>::use_at) ? P.at(0,0) : P[0];
   }
@@ -152,12 +145,7 @@ as_scalar_redirect<3>::apply(const Glue< Glue<T1, T2, glue_times>, T3, glue_time
     {
     const Mat<eT> tmp(X);
     
-    if(tmp.n_elem != 1)
-      {
-      arma_debug_check(true, "as_scalar(): expression doesn't evaluate to exactly one element");
-      
-      return Datum<eT>::nan;
-      }
+    arma_debug_check( (tmp.n_elem != 1), "as_scalar(): expression must evaluate to exactly one element" );
     
     return tmp[0];
     }
@@ -234,12 +222,7 @@ as_scalar_diag(const Base<typename T1::elem_type,T1>& X)
   const unwrap<T1>   tmp(X.get_ref());
   const Mat<eT>& A = tmp.M;
   
-  if(A.n_elem != 1)
-    {
-    arma_debug_check(true, "as_scalar(): expression doesn't evaluate to exactly one element");
-    
-    return Datum<eT>::nan;
-    }
+  arma_debug_check( (A.n_elem != 1), "as_scalar(): expression must evaluate to exactly one element" );
   
   return A.mem[0];
   }
@@ -311,16 +294,16 @@ template<typename T1, typename T2>
 arma_warn_unused
 arma_inline
 typename T1::elem_type
-as_scalar(const Glue<T1, T2, glue_times>& X, const typename arma_not_cx<typename T1::elem_type>::result* junk = 0)
+as_scalar(const Glue<T1, T2, glue_times>& X, const typename arma_not_cx<typename T1::elem_type>::result* junk = nullptr)
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
   if(is_glue_times_diag<T1>::value == false)
     {
-    const sword N_mat = 1 + depth_lhs< glue_times, Glue<T1,T2,glue_times> >::num;
+    constexpr uword N_mat = 1 + depth_lhs< glue_times, Glue<T1,T2,glue_times> >::num;
     
-    arma_extra_debug_print(arma_str::format("N_mat = %d") % N_mat);
+    arma_extra_debug_print(arma_str::format("N_mat = %u") % N_mat);
     
     return as_scalar_redirect<N_mat>::apply(X);
     }
@@ -340,67 +323,14 @@ as_scalar(const Base<typename T1::elem_type,T1>& X)
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::elem_type eT;
-  
   const Proxy<T1> P(X.get_ref());
   
-  if(P.get_n_elem() != 1)
-    {
-    arma_debug_check(true, "as_scalar(): expression doesn't evaluate to exactly one element");
-    
-    return Datum<eT>::nan;
-    }
+  arma_debug_check( (P.get_n_elem() != 1), "as_scalar(): expression must evaluate to exactly one element" );
   
   return (Proxy<T1>::use_at) ? P.at(0,0) : P[0];
   }
 
 
-// ensure the following two functions are aware of each other
-template<typename T1,              typename   eop_type> inline arma_warn_unused typename T1::elem_type as_scalar(const   eOp<T1,       eop_type>& X);
-template<typename T1, typename T2, typename eglue_type> inline arma_warn_unused typename T1::elem_type as_scalar(const eGlue<T1, T2, eglue_type>& X);
-
-
-
-template<typename T1, typename eop_type>
-arma_warn_unused
-inline
-typename T1::elem_type
-as_scalar(const eOp<T1, eop_type>& X)
-  {
-  arma_extra_debug_sigprint();
-  
-  typedef typename T1::elem_type eT;
-  
-  const eT val = as_scalar(X.P.Q);
-  
-  return eop_core<eop_type>::process(val, X.aux);
-  }
-
-
-
-template<typename T1, typename T2, typename eglue_type>
-inline
-arma_warn_unused
-typename T1::elem_type
-as_scalar(const eGlue<T1, T2, eglue_type>& X)
-  {
-  arma_extra_debug_sigprint();
-  
-  typedef typename T1::elem_type eT;
-  
-  const eT a = as_scalar(X.P1.Q);
-  const eT b = as_scalar(X.P2.Q);
-  
-  // the optimiser will keep only one return statement
-  
-       if(is_same_type<eglue_type, eglue_plus >::yes) { return a + b; }
-  else if(is_same_type<eglue_type, eglue_minus>::yes) { return a - b; }
-  else if(is_same_type<eglue_type, eglue_div  >::yes) { return a / b; }
-  else if(is_same_type<eglue_type, eglue_schur>::yes) { return a * b; }
-  }
-
-
-
 template<typename T1>
 arma_warn_unused
 inline
@@ -411,12 +341,7 @@ as_scalar(const Gen<T1, gen_randu>& X)
   
   typedef typename T1::elem_type eT;
   
-  if( (X.n_rows != 1) || (X.n_cols != 1) )
-    {
-    arma_debug_check(true, "as_scalar(): expression doesn't evaluate to exactly one element");
-    
-    return Datum<eT>::nan;
-    }
+  arma_debug_check( ((X.n_rows != 1) || (X.n_cols != 1)), "as_scalar(): expression must evaluate to exactly one element" );
   
   return eT(arma_rng::randu<eT>());
   }
@@ -433,12 +358,7 @@ as_scalar(const Gen<T1, gen_randn>& X)
   
   typedef typename T1::elem_type eT;
   
-  if( (X.n_rows != 1) || (X.n_cols != 1) )
-    {
-    arma_debug_check(true, "as_scalar(): expression doesn't evaluate to exactly one element");
-    
-    return Datum<eT>::nan;
-    }
+  arma_debug_check( ((X.n_rows != 1) || (X.n_cols != 1)), "as_scalar(): expression must evaluate to exactly one element" );
   
   return eT(arma_rng::randn<eT>());
   }
@@ -453,16 +373,9 @@ as_scalar(const BaseCube<typename T1::elem_type,T1>& X)
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::elem_type eT;
-  
   const ProxyCube<T1> P(X.get_ref());
   
-  if(P.get_n_elem() != 1)
-    {
-    arma_debug_check(true, "as_scalar(): expression doesn't evaluate to exactly one element");
-    
-    return Datum<eT>::nan;
-    }
+  arma_debug_check( (P.get_n_elem() != 1), "as_scalar(): expression must evaluate to exactly one element" );
   
   return (ProxyCube<T1>::use_at) ? P.at(0,0,0) : P[0];
   }
@@ -491,12 +404,7 @@ as_scalar(const SpBase<typename T1::elem_type, T1>& X)
   const unwrap_spmat<T1>  tmp(X.get_ref());
   const SpMat<eT>& A    = tmp.M;
   
-  if(A.n_elem != 1)
-    {
-    arma_debug_check(true, "as_scalar(): expression doesn't evaluate to exactly one element");
-    
-    return Datum<eT>::nan;
-    }
+  arma_debug_check( (A.n_elem != 1), "as_scalar(): expression must evaluate to exactly one element" );
   
   return A.at(0,0);
   }
