@@ -37,7 +37,7 @@ eig_gen
   
   arma_debug_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
   
-  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn( "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
+  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn_level(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
   
   Col<eT> eigvals;
   Mat<eT> eigvecs;
@@ -74,7 +74,7 @@ eig_gen
   
   arma_debug_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
   
-  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn( "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
+  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn_level(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
   
   Mat<eT> eigvecs;
   
@@ -83,7 +83,7 @@ eig_gen
   if(status == false)
     {
     eigvals.soft_reset();
-    arma_debug_warn("eig_gen(): decomposition failed");
+    arma_debug_warn_level(3, "eig_gen(): decomposition failed");
     }
   
   return status;
@@ -110,7 +110,7 @@ eig_gen
   
   arma_debug_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
   
-  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn( "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
+  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn_level(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
   
   const bool status = (sig == 'b') ? auxlib::eig_gen_balance(eigvals, eigvecs, true, expr.get_ref()) : auxlib::eig_gen(eigvals, eigvecs, true, expr.get_ref());
   
@@ -118,7 +118,7 @@ eig_gen
     {
     eigvals.soft_reset();
     eigvecs.soft_reset();
-    arma_debug_warn("eig_gen(): decomposition failed");
+    arma_debug_warn_level(3, "eig_gen(): decomposition failed");
     }
   
   return status;
@@ -148,7 +148,7 @@ eig_gen
   
   arma_debug_check( ((sig != 'n') && (sig != 'b')), "eig_gen(): unknown option" );
   
-  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn( "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
+  if( auxlib::crippled_lapack(expr) && (sig == 'b') )  { arma_debug_warn_level(1,  "eig_gen(): 'balance' option ignored due to linking with crippled lapack"); }
   
   const bool status = (sig == 'b') ? auxlib::eig_gen_twosided_balance(eigvals, leigvecs, reigvecs, expr.get_ref()) : auxlib::eig_gen_twosided(eigvals, leigvecs, reigvecs, expr.get_ref());
   
@@ -157,7 +157,7 @@ eig_gen
      eigvals.soft_reset();
     leigvecs.soft_reset();
     reigvecs.soft_reset();
-    arma_debug_warn("eig_gen(): decomposition failed");
+    arma_debug_warn_level(3, "eig_gen(): decomposition failed");
     }
   
   return status;
